@@ -1,4 +1,4 @@
-from .core.isql import iSQL
+from .core.isql import iSQL, iSqlDF
 
 from .utils.paths import (
     base_dir, tests_dir, package_dir,
