@@ -46,7 +46,7 @@ exe = typer.Typer(
 
 dev = typer.Typer(
     name="dev",
-    help=f"""Developer tools 🧑‍💻.
+    help=f"""Developer tools 💻.
     [yellow][bold]Aliases:[/] d, dev[/]
     """,
     rich_markup_mode="rich",
@@ -60,7 +60,8 @@ def executer(
     out: str = typer.Option(None, "-o", "--out", "--out-file", help="The output file 📰, defaults to rich table 📊 on console"),
     override_default_dir: str = typer.Option(None, "-od", "--override-default-dir", help="Override the default directory 📁. Defaults to `~/pisql` 😉"),
     ) -> None:
-    """Execute a query ❓ against a Sybase ASE database 🧑‍💻. Accepts a .sql file 📄"""
+    """Execute a query ❓ against a Sybase ASE database 📦. Accepts a .sql file 📄"""
+    
     file = Path(file)
 
     if not override_default_dir:
@@ -82,21 +83,72 @@ def executer(
 
         if out is None:
             csv_out = df.write_csv(file=csv_file)
-            parquet_out = df.write_parquet(file=parquet_file)
+            parquet_out = df.write_parquet(file=parquet_file,  compression="lz4")
             records = orjson.loads(df.write_json(row_oriented=True))
             console.print(tableFromRecords(records, theme="default"))
         else:
             outfile = dir / file.name
             csv_out = df.write_csv(file=csv_file)
-            parquet_out = df.write_parquet(file=parquet_file)
+            parquet_out = df.write_parquet(file=parquet_file, compression="lz4")
             if out.lower() in ["json", "excel"]:
                 errors.print(f"[bold red]Output format {out} not supported yet with the base version.[/]", style="bold red")
                 errors.print(f"[dim yellow]Please install `pandas` to get excel support[/]")
                 sys.exit(1)
         pbar.update(task, advance=50)
-        pbar.update(task, description=f"✅ Donew writing results to {dir}")
+        pbar.update(task, description=f"✅ Donew writing results to {dir}", completed=True)
         sys.exit(0)
 
+@exe.command(name=">>", help="Execute a query ❓ against a Sybase ASE database 📦. Accepts a dir 📁 of .sql files 📄 or a list of files")
+def runall(
+    args : List[Path],
+    dir: str = typer.Option(None, "-d", "--dir", help="the base directory of all the files")
+    ) -> None:
+    """Execute a query ❓ against a Sybase ASE database 📦. Accepts a dir 📁 of .sql files 📄 or a list of files"""
+    files = []
+
+    if dir is not None:
+        dir = Path(dir)
+        if dir.is_dir():
+            files += [file for file in dir.iterdir() if file.suffix == ".sql"]
+        else:
+            errors.print(f"[bold red]Invalid directory {dir}[/]", style="bold red")
+            sys.exit(1)
+    
+    for arg in args:
+        arg = Path(arg)
+        if arg.is_dir():
+            files += [file for file in arg.iterdir() if file.suffix == ".sql"]
+        elif arg.is_file():
+            files.append(arg)
+        else:
+            errors.print(f"[bold red]Invalid file/dir {arg}[/]", style="bold red")
+            sys.exit(1)
+    for file in files:
+        executer(file=file)
+
+
+def listTablesServer() -> None:
+    """List all tables 📓 in the server 📦"""
+    querytxt = """
+        SELECT t.name, c.name
+        FROM sysobjects t, syscolumns c
+        WHERE t.id = c.id AND t.type IN ('U', 'V')
+        """
+    df = isql.query(querytxt)
+    console.print(df)
+    df.write_parquet(pisql_home / "results" / "tables.parquet", compression="lz4")
+
+@exe.command(name="tables?", help="List all tables 📓 in the server 📦. [bold yellow]Alias: `?`[/]")
+def listTables() -> None:
+    """List all tables 📓 in the server 📦"""
+    listTablesServer()
+
+@exe.command(name="?", help="List all tables 📓 in the server 📦")
+def listTables() -> None:
+    """List all tables 📓 in the server 📦"""
+    listTablesServer()
+
+
 @dev.command(name="test", help="Run tests 🧪")
 def test(
     test_type: str = typer.Argument(..., help="The type of test to run 🧪"),
@@ -130,14 +182,6 @@ def test(
 
         if not len(target):
             raise typer.BadParameter(f"Couldn't find a test with name {selector}")
-        
-        target = target.pop()
-
-        raw_out = raw_outs[target]
-
-        columns, rows = isql.dataParse(raw_out)
-
-        console.print(tableFromRecords(parsed))
 
 @dev.command(name="view", help="See the raw data 📰 🧪")
 def test(
